# The Keymaster

1. Press 'c'. Nothing should be logged on console.
2. Press 'o' or Enter or Cursor ←. Console should log function call.
3. Press 'i'. Switches scope to 'issues'.
4. Press 'c'. Console should log function call.
5. Press 'o' or Enter or Cursor ←. Console should log function call.
6. Press and hold 'm'. Console should log a message every second.
7. Every second console should log a message listing all the currently pressed keycodes.

At any time, try pressing ⌘+right, shift+left or ctrl+shift+alt+d.

When a input, a select or a textarea element is focused, key inputs should be ignored.